@@ -1,11 +1,13 @@
-# Copyrights 2003-2015 by [Mark Overmeer].
+# Copyrights 2003-2021 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of perl distribution OODoc.  It is licensed under the
+# same terms as Perl itself: https://spdx.org/licenses/Artistic-2.0.html
 
 package OODoc;
 use vars '$VERSION';
-$VERSION = '2.01';
+$VERSION = '2.02';
 
 use base 'OODoc::Object';
 
@@ -260,10 +262,12 @@ sub prepare(@)
         $manual->expand;
     }
 
-    info "Create inheritance chapter";
+    info "Create inheritance chapters";
     foreach my $manual ($self->manuals)
-    {   trace "  create inheritance for $manual";
-        $manual->createInheritance;
+    {    next if $manual->chapter('INHERITANCE');
+
+         trace "  create inheritance for $manual";
+         $manual->createInheritance;
     }
 
     $self;
