@@ -1,11 +1,13 @@
-# Copyrights 2003-2015 by [Mark Overmeer].
+# Copyrights 2003-2021 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
+# This code is part of perl distribution OODoc.  It is licensed under the
+# same terms as Perl itself: https://spdx.org/licenses/Artistic-2.0.html
 
 package OODoc::Parser::Markov;
 use vars '$VERSION';
-$VERSION = '2.01';
+$VERSION = '2.02';
 
 use base 'OODoc::Parser';
 
@@ -161,7 +163,10 @@ sub parse(@)
     while(my $line = $in->getline)
     {   my $ln = $in->input_line_number;
 
-        if(!$self->inDoc && $line =~ s/^(\s*package\s*([\w\-\:]+)\;)//)
+        if(    !$self->inDoc
+            && $line !~ m/^\s*package\s*DB\s*;/
+            && $line =~ s/^(\s*package\s*([\w\-\:]+)\s*\;)//
+          )
         {   $out->print($1);
             my $package = $2;
 
@@ -270,7 +275,7 @@ sub currentManual(;$)
 {   my $self = shift;
     @_ ? $self->{OPM_manual} = shift : $self->{OPM_manual};
 }
-    
+
 #-------------------------------------------
 
 
@@ -468,7 +473,7 @@ sub closeSubroutine()
 sub docOption($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
-    unless($line =~ m/^\=option\s+(\S+)\s*(.+?)\s*$/ )
+    unless($line =~ m/^\=option\s+(\S+)\s+(.+?)\s*$/ )
     {   warn "WARNING: option line incorrect in $fn line $ln:\n$line";
         return;
     }
@@ -496,7 +501,7 @@ sub docOption($$$$)
 sub docDefault($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
-    unless($line =~ m/^\=default\s+(\S+)\s*(.+?)\s*$/ )
+    unless($line =~ m/^\=default\s+(\S+)\s+(.+?)\s*$/ )
     {   warn "WARNING: default line incorrect in $fn line $ln:\n$line";
         return;
     }
@@ -521,7 +526,7 @@ sub docDefault($$$$)
 sub docRequires($$$$)
 {   my ($self, $match, $line, $fn, $ln) = @_;
 
-    unless($line =~ m/^\=requires\s+(\w+)\s*(.+?)\s*$/ )
+    unless($line =~ m/^\=requires\s+(\w+)\s+(.+?)\s*$/ )
     {   warn "WARNING: requires line incorrect in $fn line $ln:\n$line";
         return;
     }
@@ -578,7 +583,7 @@ sub docExample($$$$)
                  || $self->{OPM_subsection}
                  || $self->{OPM_section}
                  || $self->{OPM_chapter};
- 
+
     die "ERROR: example outside chapter in $fn line $ln\n"
        unless defined $container;
 
@@ -855,7 +860,7 @@ sub cleanupHtml($$$;$)
         s#(?:\A|\n)\=item\s*(?:\*\s*)?([^\n]*)#\n<li><b>$1</b><br />#gms;
         s#(?:\A|\s*)\=back\b#\n</ul>#gms;
         s#^=pod\b##gm;
- 
+
         # when F<> contains a URL, it will be used. However, when it
         # contains a file, we cannot do anything with it yet.
         s#\bF\<(\w+\://[^>]*)\>#<a href="$1">$1</a>#g;
